@@ -13,8 +13,26 @@ class XmlElement:
         """
         self.name = n
         self.attributes = a
+        for attribute_key in a.keys():
+            self.__add_xml_attribute_attribute(attribute_key)
         self.subelements = s
+        self.__add_subelement_attribute(s)
         self.text = t
+    
+    def __add_subelement_attribute(self, subelements:List[XmlElement]) -> None:
+        """Internal function to allow the shorthand . operator to access findall()"""
+        for subelement in subelements:
+            setattr(self, subelement.name, self.findall(subelement.name))
+
+
+    def __add_xml_attribute_attribute(self, attribute_key:str) -> None:
+        """Internal function to allow the shorthand . operator to access xml attributes if the attribute is not already used.
+        .text, .attributes, .subelements etc. or any subelement with the same name will be paramount.
+        """
+        if not hasattr(self, attribute_key):
+            def get_attribute(self, key:str):
+                return self.attributes[key]
+            setattr(self, attribute_key, get_attribute(self, attribute_key))
 
 
     def set(self, key: str, value:str) -> None:
@@ -23,6 +41,7 @@ class XmlElement:
         key -- XML attribute name
         value -- XML attribute value
         """
+        self.__add_xml_attribute_attribute(key)
         self.attributes = { **self.attributes, **{key: value} }
 
 
@@ -31,6 +50,7 @@ class XmlElement:
         Keyword arguments:
         subelement -- XmlElement
         """
+        self.__add_subelement_attribute([subelement])
         self.subelements = [ *self.subelements, subelement]
 
 
@@ -39,6 +59,7 @@ class XmlElement:
         Keyword arguments:
         subelement -- Set of XmlElements
         """
+        self.__add_subelement_attribute(subelements)
         self.subelements = [ *self.subelements, *subelements ]
         
 
